import argparse
import sys
import uvicorn

def start_api(port: int):
    uvicorn.run("achakra.api:app", port=port, log_level="info")

def main():
	parser = argparse.ArgumentParser()
	subparsers = parser.add_subparsers(help="possible commands", dest="command")
	some_parser = subparsers.add_parser("achakra", help="")
	some_parser.add_argument("-p", "--port", help="port to run on", type=int)

	if len(sys.argv) == 1:
		parser.print_help()
		sys.exit(1)

	args = parser.parse_args()

	if args.command == "achakra":
		start_api(port = args.port)

if __name__ == "__main__":
	main()


from setuptools import setup

setup(
   name='achakra',
   version='1.0.0',
   description='A useful module',
   author='Aneesh Chakravarthula',
   author_email='srianeesh328@gmail.com',
   packages=['achakra'],  #same as name
   install_requires=['wheel', 'bar'], #external packages as dependencies
)


import requests
import lxml.html
import argparse
import sqlite3
import sys

def get_rating(tid: str) :
    """
    Given an imdb title id, return the title's rating.
    """
    resp = requests.get(f"https://www.imdb.com/title/{tid}", stream=True)
    resp.raw.decode_content = True
    tree = lxml.html.parse(resp.raw)
    element = tree.xpath("//div[@data-testid='hero-rating-bar__aggregate-rating__score']/span")[0]
    return float(element.text)


    
